@@ -331,7 +331,7 @@ class AbstractInterface():
     self.__button.get_image().set_from_pixbuf(self.__smi_cacher.get(key))
 
   def __set_sai(self, key):
-    if any(self.state['show']):
+    if any(self.state['show']) and self.get_config_value('show-sa-icon'):
       if self.state['show'][self.state['value']]:
         self.__set_status_area_icon(self.__name, key)
       else: 
